PCB Environment: dsn::Track Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Fields
dsn::Track Struct Reference

## Data Fields
double | start_x
double | start_y
double | end_x
double | end_y
int | start_z
int | end_z
double | default_width
double | default_via_diameter
std::vector< Segment > | segments
std::vector< Via > | vias

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp